# What is DROPStomo?
DROPStomo is a python based software package for performing state and process tomography in the context of finite-dimensional Wigner representation on near-term quantum devices. This is a phase-space tomography approach to recover the finite-dimensional Wigner representations, with a particular focus on the [DROPS](https://spindrops.org/) (Discrete Representation of OPeratorS) representation. 

This package is based on Qiskit framework and can be easily adaptable for other frameworks. The package can be plugged in directly into simulators or quantum devices. 

## Installation
```bash
pip install DROPStomo
```
## How to use?
Currently, Wigner state tomography is available for single and two qubit system, whereas Wigner process tomography is available for single qubit system. For usage please see the example files.
